@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # thoth-adviser
-# Copyright(C) 2019, 2020 Fridolin Pokorny
+# Copyright(C) 2019 - 2021 Fridolin Pokorny
 #
 # This program is free software: you can redistribute it and / or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,6 +28,11 @@ from .unit import Unit
 class Boot(Unit):
     """Boot base class implementation."""
 
+    @staticmethod
+    def is_boot_unit_type() -> bool:
+        """Check if this unit is of type boot."""
+        return True
+
     @abc.abstractmethod
     def run(self) -> None:
         """Run main entry-point for boot units."""
